@@ -2,7 +2,6 @@
 #'
 #' @description An interface to the QuickJS lightweight Javascript engine
 #'
-#' @docType package
 #' @name QuickJSR-package
 #' @aliases QuickJSR
 #' @useDynLib QuickJSR, .registration = TRUE
@@ -11,4 +10,4 @@
 #' @importFrom R6 R6Class
 #' @importFrom Rcpp sourceCpp Rcpp.plugin.maker
 #'
-NULL
+"_PACKAGE"
